pub fn parse_all_python_packages(
index_root: &Path,
) -> Result<Vec<PythonPackage>>Expand description
Parse all Python packages in a monorepo and track their project roots
pub fn parse_all_python_packages(
index_root: &Path,
) -> Result<Vec<PythonPackage>>Parse all Python packages in a monorepo and track their project roots